#!/bin/bash

# Update the NTP log file location
sed 's:/opt/:/home/spectracom/:' < /etc/ntp/ntp.conf > /etc/ntp/ntp.conf-
rm /etc/ntp/ntp.conf
mv /etc/ntp/ntp.conf- /etc/ntp/ntp.conf

# Update the Auth and other system log file locations
sed 's:/opt/:/home/spectracom/:' < /etc/syslog.conf > /etc/syslog.conf-
rm /etc/syslog.conf
mv /etc/syslog.conf- /etc/syslog.conf

# Ensure discstats directory exists and has correct permissions
mkdir -p /home/spectracom/log/discstats
chmod 775 /home/spectracom/log/discstats

# Remove the /etc/issue file if it is used for SecureSync Version
cat /etc/issue | grep "Spectracom SecureSync Version"

# Above lines returns 0 if the string is found and 1 if not and 2 on error
if [ "$?" -eq "0" ]
then
    rm /etc/issue
fi

# Note: for 4.3.1, mkird.sh backups httpd.conf! Upgrade only from 4.2.1!

# Move the upgrade kernel and ram disk to /boot
mv /opt/upgrade/temp/upkernel /opt/upgrade/temp/uprd.img.gz /boot

# Change owner and group to root
chown root:root /boot/upkernel /boot/uprd.img.gz

# Write a new menu.lst file to boot upgrade kernel with ram disk
echo "
default=0
timeout=1
color green/black light-green/black
title Live Linux 2.6.1 Upgrade
    kernel --no-mem-option /boot/upkernel ramdisk_size=128000
    initrd /boot/uprd.img.gz
title Vile Linux  (Failover Image)
    root (hd0,0)
    kernel --no-mem-option /boot/kernel root=/dev/hda1
" > /boot/grub/menu.lst

# Add PamaceaNoIpCheck if not already present
if ! grep "PamaceaNoIpCheck" /etc/apache/httpd.conf > /dev/null 2>&1
then
    sed '
	/PamaceaNoSSL/ a\
	\
\   PamaceaNoIpCheck On
	'< /etc/apache/httpd.conf > /etc/apache/httpd.conf-
	rm /etc/apache/httpd.conf
	mv /etc/apache/httpd.conf- /etc/apache/httpd.conf
fi

# Pamacea bug, if session length is 0, only one user can be logged on at a time
sed 's/PamaceaSessionLength 0/PamaceaSessionLength 36000/' < /etc/apache/httpd.conf > /etc/apache/httpd.conf-
	rm /etc/apache/httpd.conf
	mv /etc/apache/httpd.conf- /etc/apache/httpd.conf

# Enable gpsmond if needed for no-GPS units with Deviation ECN 2592 applied
if [ -e /etc/rc.d/rc3.d/_S57gpsmond ]
then
    mv /etc/rc.d/rc3.d/_S57gpsmond /etc/rc.d/rc3.d/S57gpsmond
fi

#
# Remove CVS lines from /etc/profile Mantis 1420
#
cat /etc/profile|grep -v "CVS">/etc/profile

#
# Correct the Apache ssl.conf file to improve security Mantis 1647
#

echo "--- /etc/apache/ssl.conf	2012-03-01 13:58:52.000000000 -0500
+++ /etc/apache/ssl.conf	2012-03-01 13:53:12.000000000 -0500
@@ -99,8 +99,9 @@
 #SSLCipherSuite ALL:!ADH:!EXPORT56:RC4+RSA:+HIGH:+MEDIUM:+SSLv2:!EXP:!eNULL

 SSLProtocol -ALL +SSLv3 +TLSv1
-
-SSLCipherSuite ALL:!aNULL:!ADH:!eNULL:!LOW:!EXP:RC4+RSA:+HIGH:+MEDIUM
+SSLHonorCipherOrder On
+#SSLCipherSuite ALL:!aNULL:!ADH:!eNULL:!LOW:!EXP:RC4-SHA:+HIGH:+MEDIUM
+SSLCipherSuite RC4-SHA:HIGH:!ADH

 #   Server Certificate:
 #   Point SSLCertificateFile at a PEM encoded certificate.  If" > /tmp/ssl.conf.patch

# Apply the ssl.conf patch
patch -p0 </tmp/ssl.conf.patch

# Apply Release 4.8.8 Security changes to /srv/www/auth/login.html
echo "--- /srv/www/auth/login.html	2012-11-26 18:33:20.000000000 -0500
+++ /srv/www/auth/login.html	2012-11-26 18:33:00.000000000 -0500
@@ -18,7 +18,7 @@
 <INPUT TYPE=hidden NAME=\"pamservice\" VALUE=\"@PAMSERVICE@\">
 <INPUT TYPE=hidden NAME=\"userfile\" VALUE=\"@USERFILE@\">
 Username<BR><INPUT TYPE=text NAME=\"username\" SIZE=16><BR />
-Password<BR><INPUT TYPE=password NAME=\"password\" SIZE=16><BR />
+Password<BR><INPUT TYPE=password AUTOCOMPLETE=off NAME=\"password\" SIZE=16><BR />
 <INPUT TYPE=submit NAME=\"log in\" VALUE=\"Log in\">
 </FORM>" > /tmp/login.html.patch
patch -p0 </tmp/login.html.patch

# Apply Release 4.8.8 Security changes to /etc/apache/httpd.conf
echo "--- /etc/apache/httpd.conf	2012-11-26 17:22:01.000000000 -0500
+++ /etc/apache/httpd.conf	2012-11-26 17:17:36.000000000 -0500
@@ -418,7 +418,8 @@
     ErrorDocument 403 /spec403err.html
     ErrorDocument 404 /spec404err.html
     ErrorDocument 500 /spec500err.html
-
+    # Bad Request handling to mitigate security vulnerability CVE-2012-0053
+    ErrorDocument 400 \"Bad Request\"
 </Directory>

 #
@@ -781,7 +782,9 @@
     ErrorDocument 403 /spec403err.html
     ErrorDocument 404 /spec404err.html
     ErrorDocument 500 /spec500err.html
-
+
+    # Bad Request handling to mitigate security vulnerability CVE-2012-0053
+    ErrorDocument 400 \"Bad Request\"

 </Directory>

@@ -1085,7 +1088,9 @@
 ErrorDocument 403 /spec403err.html
 ErrorDocument 404 /spec404err.html
 ErrorDocument 500 /spec500err.html
-
+    # Bad Request handling to mitigate security vulnerability CVE-2012-0053
+    ErrorDocument 400 \"Bad Request\"
+
 #
 # Putting this all together, we can internationalize error responses.
 #
@@ -1190,6 +1195,10 @@
 #
 # Bring in additional module-specific configurations
 #
+<IfModule headers_module>
+Header always append X-Frame-Options SAMEORIGIN
+</IfModule>
+
 <IfModule mod_ssl.c>
     Include /etc/apache/ssl.conf
 </IfModule>" > /tmp/httpd.conf.patch
patch -p0 </tmp/httpd.conf.patch

#
# Modify the EEPROMs for the Multi-Ethernet Option Card, if necessary
#

# Install the ethtool executable from the bundle, if not already installed
if [ ! -f /usr/sbin/ethtool ] && [ -f /opt/upgrade/ethtool ]
then
    /bin/install /opt/upgrade/ethtool /usr/sbin/
fi

# If the fixeep script is present, execute it on each network interface on the
# multi-ethernet option card
if [ -f /opt/upgrade/fixeep-82574_83.sh ]
then
    /bin/chmod +x /opt/upgrade/fixeep-82574_83.sh
    /opt/upgrade/fixeep-82574_83.sh eth1
    /opt/upgrade/fixeep-82574_83.sh eth2
    /opt/upgrade/fixeep-82574_83.sh eth3
fi

# Correct permissions for configuration files
chmod 664 /home/spectracom/config/*

# Remove all but the last GR_SetMode commands from the ktsif.conf file
cat /home/spectracom/config/ktsif.conf|grep GR_SetMode|tail -1 > /tmp/ktsif.gps
cat /home/spectracom/config/ktsif.conf|grep -v GR_SetMode > /tmp/ktsif.conf
cat /tmp/ktsif.gps >> /tmp/ktsif.conf
mv /tmp/ktsif.conf /home/spectracom/config/ktsif.conf
chmod 660 /home/spectracom/config/ktsif.conf

# Change dhclient files if DHCP enabled to disable static lease
for i in 0 1 2 3
do
    if grep "0.0.0.0/32" /etc/dhclient-eth$i.conf > /dev/null 2>&1
    then
        sed '
        /lease/,+1 c\
lease {\
    interface "ethnone";
        '< /etc/dhclient-eth$i.conf > /etc/dhclient-eth$i.conf-
        rm /etc/dhclient-eth$i.conf
        mv /etc/dhclient-eth$i.conf- /etc/dhclient-eth$i.conf
    fi
done

# Fix ETP_SetCfg commands for added SSM parameters in ktsif.conf
filelist="/home/spectracom/config/ktsif.conf"
filelist="$filelist /home/spectracom/default/home/spectracom/config/ktsif.conf"
for filename in $filelist
do
    cat $filename | while read confline
    do
        if [[ "$confline" == *"ETP_SetCfg"* ]]
        then
            tokenlen=$(echo "$confline" | wc -w)
            case "$tokenlen" in
                "5"|"6")
                    echo "$confline 0 0" >> /tmp/ktsif.conf-
                    ;;
                *)
                    echo "$confline" >> /tmp/ktsif.conf-
                    ;;
            esac
        else
            echo "$confline" >> /tmp/ktsif.conf-
        fi
    done
    mv /tmp/ktsif.conf- $filename
    chmod 660 $filename
done

# Fix pam_tally reset in all existing pam.d config files
dirlist="/home/spectracom/default/etc/pam.d/"
dirlist="$dirlist /etc/pam.d/"
dirlist="$dirlist /etc/pam.d/radiusldap/"
dirlist="$dirlist /etc/pam.d/ldap/"
dirlist="$dirlist /etc/pam.d/radius/"
dirlist="$dirlist /etc/pam.d/default/"
filelist="httpd login pure-ftpd sshd"
for dir in $dirlist
do
    for file in $filelist
    do
        if [ -e $dir$file ]
        then
            if grep "account required pam_tally.so reset" $dir$file > /dev/null 2>&1
            then :
            else
                cat $dir$file | while read confline
                do
                    if [[ "$confline" == *"account required pam_securetty.so"* ]]
                    then
                        echo "$confline" >> /tmp/$file-
                        echo "account required pam_tally.so reset" >> /tmp/$file-
                    else
                        echo "$confline" >> /tmp/$file-
                    fi
                done
                mv /tmp/$file- $dir$file
                chmod 644 $dir$file
            fi
        fi
    done
done

# Flush all file system buffers
sync
